# Super Cereal

*Serialize Python objects for realz. I'm super cereal.*

[![Tests](https://github.com/cowboygneox/super-cereal/actions/workflows/test.yml/badge.svg)](https://github.com/cowboygneox/super-cereal/actions/workflows/test.yml)
[![Latest Stable Version](https://img.shields.io/pypi/v/super-cereal)](https://pypi.org/project/super-cereal/)
